==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/SciFigs/src/LayerPainter.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-02-12
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef LAYERPAINTER_H
#define LAYERPAINTER_H

#include "LayerPainterRequest.h"

namespace SciFigs {

class LayerPainterThread;

class LayerPainter : public QObject
{
  Q_OBJECT
public:
  LayerPainter();
  ~LayerPainter();

  void clear(  GraphContent * gc);
  int terminate(GraphContent * gc);
  void paint(LayerPainterRequest * r);
private:
  friend class LayerPainterThread;

  QList<LayerPainterThread *> _threads;
  QQueue<LayerPainterRequest *> _queue;
  Mutex _queueMutex;
  Mutex _waitMutex;
  QWaitCondition _paintEvent;
  QWaitCondition _paintTerminateEvent;
};

} // namespace SciFigs

#endif // LAYERPAINTER_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/SciFigs/src/LayerPainter.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-02-12
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef LAYERPAINTER_H
#define LAYERPAINTER_H

#include "LayerPainterRequest.h"

namespace SciFigs {

class LayerPainterThread;

class LayerPainter : public QObject
{
  Q_OBJECT
public:
  LayerPainter();
  ~LayerPainter();

  void clear(  GraphContents * gc);
  int terminate(GraphContents * gc);
  void paint(LayerPainterRequest * r);
private:
  friend class LayerPainterThread;

  QList<LayerPainterThread *> _threads;
  QQueue<LayerPainterRequest *> _queue;
  Mutex _queueMutex;
  Mutex _waitMutex;
  QWaitCondition _paintEvent;
  QWaitCondition _paintTerminateEvent;
};

} // namespace SciFigs

#endif // LAYERPAINTER_H
